@@ -1,12 +1,36 @@
 /****************************************************************************
  *
- * $Id: sl2pl.c,v 1.4 2003/08/24 00:56:03 dburke Exp $
+ * $Id: sl2pl.c,v 1.5 2005/01/03 18:06:17 dburke Exp $
  *
  * sl2pl.c
  *   Conversion routines between S-Lang and Perl data types.
  *
  ****************************************************************************/
 
+/*
+This software is Copyright (C) 2003, 2004, 2005 Smithsonian
+Astrophysical Observatory. All rights are reserved.
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License as
+published by the Free Software Foundation; either version 2 of the
+License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA
+
+Or, surf on over to
+
+  http://www.fsf.org/copyleft/gpl.html
+*/
+
 #include "util.h"
 #include "pdl.h"
 #include "sl2pl.h"
